@@ -8,13 +8,13 @@
 (def current-version (string/trim (slurp (io/resource "CLOJURE_LSP_VERSION"))))
 (def class-dir "target/classes")
 (def basis {:project "deps.edn"})
-(def jar-file (format "target/%s.jar" (name lib)))
+(def server-file (format "target/%s.jar" (name lib)))
 
 (defn clean [_]
   (b/delete {:path "target"}))
 
 (defn pom [opts]
-  (b/write-pom {:target ""
+  (b/write-pom {:class-dir class-dir
                 :lib lib
                 :version current-version
                 :basis (b/create-basis (update basis :aliases concat (:extra-aliases opts)))
@@ -24,16 +24,16 @@
 (defn jar [opts]
   (clean nil)
   (pom opts)
-  (b/copy-dir {:src-dirs ["src"]
+  (b/copy-dir {:src-dirs ["src" "resources"]
                :target-dir class-dir})
   (b/jar {:class-dir class-dir
-          :jar-file jar-file}))
+          :jar-file server-file}))
 
 (defn deploy-clojars [opts]
   (jar opts)
   ((requiring-resolve 'deps-deploy.deps-deploy/deploy)
    (merge {:installer :remote
-           :artifact jar-file
+           :artifact server-file
            :pom-file "pom.xml"}
           opts))
   opts)
