@@ -1,8 +1,10 @@
 (ns clojure-lsp.feature.completion
   (:require
    [clojure-lsp.common-symbols :as common-sym]
+   [clojure-lsp.dep-graph :as dep-graph]
    [clojure-lsp.feature.add-missing-libspec :as f.add-missing-libspec]
    [clojure-lsp.feature.completion-snippet :as f.completion-snippet]
+   [clojure-lsp.feature.format]
    [clojure-lsp.feature.hover :as f.hover]
    [clojure-lsp.parser :as parser]
    [clojure-lsp.queries :as q]
@@ -34,7 +36,7 @@
    :clojure-core
    :clojurescript-core
    :java-usages
-   :java-built-in
+   :java-class-definitions
    :snippet])
 
 (def priority-kw->number
@@ -86,9 +88,12 @@
          (or arglist-strs macro))
     :function
 
-    (#{:var-definitions :var-usages :locals} bucket)
+    (#{:var-definitions :locals} bucket)
     :variable
 
+    (#{:var-usages} bucket)
+    :reference
+
     (#{:local-usages} bucket)
     :value
 
@@ -108,9 +113,12 @@
     (#{:keyword-usages :keyword-definitions} bucket)
     (keyword-element->str element cursor-alias priority)
 
-    (#{:namespace-alias :namespace-usages} bucket)
+    (#{:namespace-alias} bucket)
     (some-> alias name)
 
+    (#{:namespace-usages} bucket)
+    (some-> element :name name)
+
     (#{:java-class-usages} bucket)
     (java-element->class-name element)
 
@@ -189,6 +197,10 @@
                    (identical? :namespace-alias bucket)
                    (some->> element :to name (str "alias to: "))
 
+                   (identical? :var-usages bucket)
+                   ;; it's always a refer
+                   (some->> element :to name (str "refer to: "))
+
                    (identical? :java-class-usages bucket)
                    (:class element)
 
@@ -205,7 +217,7 @@
       detail (assoc :detail detail)
       :always (completion-item-with-unresolved-documentation
                 {:name (-> element :name str)
-                 :filename (:filename element)
+                 :uri (:uri element)
                  :name-row (:name-row element)
                  :name-col (:name-col element)}
                 resolve-support))))
@@ -226,6 +238,10 @@
   [_bucket matches-fn _cursor-element]
   (name-matches-xf matches-fn))
 
+(defmethod bucket-elems-xf :namespace-usages
+  [_bucket matches-fn _cursor-element]
+  (name-matches-xf matches-fn))
+
 (defmethod bucket-elems-xf :var-definitions
   [_bucket matches-fn {cursor-from :from cursor-bucket :bucket}]
   (let [on-var-usage? (identical? :var-usages cursor-bucket)]
@@ -233,6 +249,12 @@
       (remove #(and on-var-usage? (not= (:ns %) cursor-from)))
       (name-matches-xf matches-fn))))
 
+(defmethod bucket-elems-xf :var-usages
+  [_bucket matches-fn _cursor-element]
+  (comp
+    (filter :refer)
+    (name-matches-xf matches-fn)))
+
 (defmethod bucket-elems-xf :keywords
   [_bucket matches-fn cursor-element]
   (comp
@@ -268,16 +290,23 @@
                                                (contains? cursor-langs (:lang %)))))
                             (get local-buckets bucket))))
             (map #(element->completion-item % nil :simple-cursor resolve-support)))
-          [:namespace-definitions :var-definitions :keyword-definitions :keyword-usages :locals :java-class-usages])))
+          [:namespace-definitions
+           :namespace-usages
+           :var-definitions
+           :var-usages
+           :keyword-definitions
+           :keyword-usages
+           :locals
+           :java-class-usages])))
 
 (defn ^:private with-definition-kws-args-element-items
-  [matches-fn {:keys [arglist-kws name-row name-col filename]} resolve-support]
+  [matches-fn {:keys [arglist-kws name-row name-col uri]} resolve-support]
   (->> (flatten arglist-kws)
        (map (fn [kw]
               {:name (str kw)
                :name-row name-row
                :name-col name-col
-               :filename filename
+               :uri uri
                :bucket :keyword-usages}))
        (filter #(matches-fn (keyword-element->str % nil nil)))
        (mapv #(element->completion-item % nil :kw-arg resolve-support))))
@@ -306,7 +335,7 @@
                               :namespace-alias
                               (filter #(= (-> % :alias str) cursor-alias))
                               seq)
-                         (->> (q/ns-aliases db)
+                         (->> (dep-graph/ns-aliases db)
                               seq))]
     (->> (concat
            (when (simple-ident? cursor-value)
@@ -390,7 +419,7 @@
             (map #(element->completion-item % alias :alias-keyword resolve-support)))
           (:analysis non-local-db))))
 
-(defn ^:private with-core-items [matches-fn {:keys [filename ns-name symbols priority]} resolve-support]
+(defn ^:private with-core-items [matches-fn {:keys [uri ns-name symbols priority]} resolve-support]
   (keep (fn [{:keys [name kind]}]
           (let [sym-name (str name)]
             (when (matches-fn sym-name)
@@ -399,15 +428,15 @@
                    :detail   (str ns-name "/" sym-name)
                    :priority priority}
                   (completion-item-with-unresolved-documentation
-                    {:filename filename
-                     :name     sym-name
-                     :ns       ns-name}
+                    {:uri  uri
+                     :name sym-name
+                     :ns   ns-name}
                     resolve-support)))))
         symbols))
 
 (defn ^:private with-clojure-core-items [matches-fn resolve-support]
   (with-core-items matches-fn
-                   {:filename "/clojure.core.clj"
+                   {:uri "file:///clojure.core.clj"
                     :ns-name "clojure.core"
                     :symbols common-sym/clj-syms
                     :priority :clojure-core}
@@ -415,26 +444,36 @@
 
 (defn ^:private with-clojurescript-items [matches-fn resolve-support]
   (with-core-items matches-fn
-                   {:filename "/cljs.core.cljs"
+                   {:uri "file:///cljs.core.cljs"
                     :ns-name "cljs.core"
                     :symbols common-sym/cljs-syms
                     :priority :clojurescript-core}
                    resolve-support))
 
-(defn ^:private with-java-items [matches-fn]
-  (concat
-    (->> common-sym/java-lang-syms
-         (filter (comp matches-fn str))
-         (map (fn [sym] {:label (str sym)
-                         :kind :class
-                         :detail (str "java.lang." sym)
-                         :priority :java-built-in})))
-    (->> common-sym/java-util-syms
-         (filter (comp matches-fn str))
-         (map (fn [sym] {:label (str sym)
-                         :kind :class
-                         :detail (str "java.util." sym)
-                         :priority :java-built-in})))))
+(defn ^:private with-java-definition-items [matches-fn cursor-value db]
+  ;; For performance reasons, we have thousands of class definitions usually
+  ;; we only consider it if user typed anything and is auto completing
+  (when (seq (str cursor-value))
+    (flatten
+      (into []
+            (comp
+              q/xf-analysis->java-class-definitions
+              (keep (fn [{:keys [class]}]
+                      (let [class-name* (delay (last (string/split class #"\.")))]
+                        (cond-> []
+
+                          (matches-fn class)
+                          (conj {:label (str class)
+                                 :kind :class
+                                 :priority :java-class-definitions})
+
+                          (and (string/starts-with? class "java.lang")
+                               (matches-fn @class-name*))
+                          (conj {:label @class-name*
+                                 :detail class
+                                 :kind :class
+                                 :priority :java-class-definitions}))))))
+            (:analysis db)))))
 
 (defn ^:private remove-first-and-last-char [s]
   (-> (string/join "" (drop-last s))
@@ -492,15 +531,14 @@
     ;; computation. To avoid this expense, we abort on comments.
     (if (= :comment (some-> cursor-loc z/tag))
       []
-      (let [filename (shared/uri->filename uri)
-            settings (settings/all db)
+      (let [settings (settings/all db)
             client-completion-item-caps (get-in db [:client-capabilities :text-document :completion :completion-item])
             resolve-support (-> (get client-completion-item-caps :resolve-support {})
                                 (update :properties set))
             support-snippets? (get client-completion-item-caps :snippet-support false)
-            non-local-db (update db :analysis dissoc filename)
-            local-buckets (get-in db [:analysis filename])
-            cursor-element (q/find-element-under-cursor db filename row col)
+            non-local-db (update db :analysis dissoc uri)
+            local-buckets (get-in db [:analysis uri])
+            cursor-element (q/find-element-under-cursor db uri row col)
             cursor-value (if (= :vector (z/tag cursor-loc))
                            ""
                            (if (z/sexpr-able? cursor-loc)
@@ -517,7 +555,7 @@
             matches-fn (partial matches-cursor? cursor-value)
             {caller-usage-row :row caller-usage-col :col} (some-> cursor-op z/node meta)
             caller-var-definition (when (and caller-usage-row caller-usage-col)
-                                    (q/find-definition-from-cursor db filename caller-usage-row caller-usage-col))
+                                    (q/find-definition-from-cursor db uri caller-usage-row caller-usage-col))
             inside-require? (edit/inside-require? cursor-loc)
             inside-refer? (edit/inside-refer? cursor-loc)
             simple-cursor? (or (simple-ident? cursor-value)
@@ -529,7 +567,7 @@
                                    (name cursor-value)
                                    (str cursor-value)))
             cursor-full-ns? (when cursor-value-or-ns
-                              (contains? (q/ns-names db) (symbol cursor-value-or-ns)))
+                              (contains? (dep-graph/ns-names db) (symbol cursor-value-or-ns)))
             items (cond
                     inside-refer?
                     (with-refer-elements matches-fn cursor-loc non-local-db resolve-support)
@@ -566,23 +604,27 @@
 
                       (and simple-cursor?
                            (supports-clj-core? uri))
-                      (into (with-java-items matches-fn))
+                      (into (with-java-definition-items matches-fn cursor-value db))
 
                       (and support-snippets?
                            simple-cursor?)
                       (merging-snippets cursor-loc next-loc function-call? matches-fn settings)))]
-        (sorting-and-distincting-items items)))))
+        (->> items
+             sorting-and-distincting-items
+             ;; Limit the returned items for better performance.
+             ;; If user needs more items one should be more specific in the completion query.
+             (take 600))))))
 
 ;;;; Resolve Completion Item (completionItem/resolve)
 
-(defn ^:private find-element-by-ns [{:keys [name ns filename]} db]
-  (q/find-definition db {:filename filename
+(defn ^:private find-element-by-ns [{:keys [name ns uri]} db]
+  (q/find-definition db {:uri uri
                          :name (symbol name)
                          :to (symbol ns)
                          :bucket :var-usages}))
 
-(defn ^:private find-element-by-position [{:keys [filename name-row name-col]} db]
-  (q/find-element-under-cursor db filename name-row name-col))
+(defn ^:private find-element-by-position [{:keys [uri name-row name-col]} db]
+  (q/find-element-under-cursor db uri name-row name-col))
 
 (defmulti ^:private resolve-unresolved (fn [unresolved-type _item _other-unresolved _args]
                                          unresolved-type))
