@@ -15,11 +15,14 @@
 
 ;;;; Filter analysis, using dep-graph
 
+(defn external-analysis [{:keys [analysis] :as db}]
+  (medley/remove-keys #(dep-graph/uri-internal? db %) analysis))
+
 (defn internal-analysis [{:keys [analysis] :as db}]
   (medley/filter-keys #(dep-graph/uri-internal? db %) analysis))
 
-(defn external-analysis [{:keys [analysis] :as db}]
-  (medley/remove-keys #(dep-graph/uri-internal? db %) analysis))
+(defn internal-plus-local-analysis [db uri]
+  (assoc (internal-analysis db) uri (get-in db [:analysis uri])))
 
 (defn ^:private uris-analysis [{:keys [analysis]} uris]
   (select-keys analysis uris))
@@ -88,7 +91,8 @@
 (def xf-analysis->protocol-impls (xf-analysis->bucket-elems :protocol-impls))
 (def xf-analysis->var-definitions (xf-analysis->bucket-elems :var-definitions))
 (def xf-analysis->var-usages (xf-analysis->bucket-elems :var-usages))
-(def xf-analysis->vars (xf-analysis->buckets-elems :var-definitions :var-usages))
+(def xf-analysis->symbols (xf-analysis->bucket-elems :symbols))
+(def xf-analysis->vars (xf-analysis->buckets-elems :var-definitions :var-usages :symbols))
 
 (defn ^:private safe-equal?
   "Fast equals for string and symbols."
@@ -254,6 +258,24 @@
     (when-not (:fallbacking? var-usage)
       (find-definition db (assoc var-usage :lang :cljs :fallbacking? true)))))
 
+(defmethod find-definition :symbols
+  [db quoted-symbol]
+  (if (:to quoted-symbol)
+    (find-definition db (assoc quoted-symbol :bucket :var-usages))
+    (let [sym (:symbol quoted-symbol)
+          lang (:lang quoted-symbol)
+          lang (if (= :edn lang)
+                 ;; when referring to qualified-symbols in edn, pretend it's
+                 ;; referenced from JVM Clojure
+                 :clj
+                 lang)]
+      (find-definition db
+                       (assoc quoted-symbol
+                              :bucket :var-usages
+                              ;; infer namespace from symbol
+                              :to (symbol (namespace sym))
+                              :lang lang)))))
+
 (defmethod find-definition :local-usages
   [db {:keys [id uri] :as _local-usage}]
   (find-first (filter #(= (:id %) id))
@@ -466,13 +488,16 @@
           (ns-and-dependents-analysis db (:ns var-definition)))))
 
 (defmethod find-references :keywords
-  [db {:keys [ns name] :as _keyword} include-declaration?]
-  (into []
-        (comp
-          (if include-declaration? xf-analysis->keywords xf-analysis->keyword-usages)
-          (xf-same-fqn ns name)
-          (medley/distinct-by (juxt :uri :name :row :col)))
-        (internal-analysis db)))
+  [db {:keys [ns name uri] :as keyword-element} include-declaration?]
+  (let [analysis (if (contains? (elem-langs keyword-element) :edn)
+                   (internal-plus-local-analysis db uri)
+                   (internal-analysis db))]
+    (into []
+          (comp
+            (if include-declaration? xf-analysis->keywords xf-analysis->keyword-usages)
+            (xf-same-fqn ns name)
+            (medley/distinct-by (juxt :uri :name :row :col)))
+          analysis)))
 
 (defmethod find-references :local
   [db {:keys [id name uri] :as element} include-declaration?]
@@ -495,6 +520,39 @@
             (medley/distinct-by (juxt :uri :name :row :col)))
           (ns-and-dependents-analysis db protocol-ns))))
 
+(defmethod find-references :symbols
+  [db quoted-symbol include-declaration?]
+  (let [analysis (if (contains? (elem-langs quoted-symbol) :edn)
+                   (internal-plus-local-analysis db (:uri quoted-symbol))
+                   (internal-analysis db))
+        lang (:lang quoted-symbol)
+        lang (if (= :edn lang)
+                     ;; when referring to qualified-symbols in edn, pretend it's
+                     ;; referenced from JVM Clojure
+               :clj
+               lang)
+        name (:name quoted-symbol)
+        original-to (:to quoted-symbol)
+        to (or original-to
+               (symbol (namespace (:symbol quoted-symbol))))]
+    (concat
+      (when include-declaration?
+        [quoted-symbol])
+
+      ;; symbols references
+      (into []
+            (comp
+              xf-analysis->symbols
+              (xf-same-fqn original-to name)
+              (medley/distinct-by (juxt :uri :name :row :col)))
+            analysis)
+
+      ;; var-usages references
+      (find-references db (assoc quoted-symbol
+                                 :bucket :var-usages
+                                 :lang lang
+                                 :to to) include-declaration?))))
+
 (defmethod find-references :default
   [_db element _]
   [element])
@@ -676,6 +734,10 @@
   (find-last (filter #(= alias (:alias %)))
              (get-in db [:analysis uri :namespace-usages])))
 
+(defn find-namespace-alias-by-alias [db uri alias]
+  (find-last (filter #(= alias (:alias %)))
+             (get-in db [:analysis uri :namespace-alias])))
+
 (defn find-element-for-rename [db from-ns from-name]
   (let [xf
         (if from-name
