@@ -21,6 +21,24 @@
     (h/load-code-and-locs "(ns foo.bar)" (h/file-uri "jar:file:///some.jar!/some-file.clj"))
     (is (= 2 (count (q/internal-analysis (h/db)))))))
 
+(deftest internal-plus-local-analysis
+  (testing "when dependency-scheme is zipfile"
+    (h/reset-components!)
+    (h/load-code-and-locs "(ns foo.bar)" (h/file-uri "file:///a.clj"))
+    (h/load-code-and-locs "(ns foo.bar)" (h/file-uri "file:///b.clj"))
+    (h/load-code-and-locs "(ns foo.bar)" (h/file-uri "zipfile:///some.jar::some-file.clj"))
+    (h/load-code-and-locs "(ns foo.bar)" (h/file-uri "zipfile:///some.jar::other-file.clj"))
+    (is (= 2 (count (q/internal-plus-local-analysis (h/db) (h/file-uri "file:///a.clj")))))
+    (is (= 3 (count (q/internal-plus-local-analysis (h/db) (h/file-uri "zipfile:///some.jar::some-file.clj"))))))
+  (testing "when dependency-scheme is jar"
+    (swap! (h/db*) shared/deep-merge {:settings {:dependency-scheme "jar"}})
+    (h/load-code-and-locs "(ns foo.bar)" (h/file-uri "file:///a.clj"))
+    (h/load-code-and-locs "(ns foo.bar)" (h/file-uri "file:///b.clj"))
+    (h/load-code-and-locs "(ns foo.bar)" (h/file-uri "jar:file:///some.jar!/some-file.clj"))
+    (h/load-code-and-locs "(ns foo.bar)" (h/file-uri "jar:file:///some.jar!/other-file.clj"))
+    (is (= 2 (count (q/internal-plus-local-analysis (h/db) (h/file-uri "file:///a.clj")))))
+    (is (= 3 (count (q/internal-plus-local-analysis (h/db) (h/file-uri "zipfile:///some.jar::some-file.clj")))))))
+
 (deftest external-analysis
   (testing "when dependency-scheme is zipfile"
     (h/reset-components!)
@@ -492,6 +510,20 @@
         '[]
         (q/find-references-from-cursor (h/db) (h/file-uri "file:///b.clj") def-r def-c false)))))
 
+(deftest find-references-in-edn
+  (h/load-code-and-locs (h/code "(ns b)"
+                                "{:a 1}") (h/file-uri "file:///b.clj"))
+  (let [[[kwd-r kwd-c]]
+        (h/load-code-and-locs (h/code "{:a 1"
+                                      " :b {|:a :foo}}") (h/file-uri "file:///a.edn"))]
+
+    (testing "from keyword outside source-path consider source-paths + uri analysis"
+      (h/assert-submaps
+        [{:name "a" :name-row 2 :name-col 2 :name-end-row 2 :name-end-col 4 :bucket :keyword-usages :uri (h/file-uri "file:///b.clj")}
+         {:name "a" :name-row 1 :name-col 2 :name-end-row 1 :name-end-col 4 :bucket :keyword-usages :uri (h/file-uri "file:///a.edn")}
+         {:name "a" :name-row 2 :name-col 6 :name-end-row 2 :name-end-col 8 :bucket :keyword-usages :uri (h/file-uri "file:///a.edn")}]
+        (q/find-references-from-cursor (h/db) (h/file-uri "file:///a.edn") kwd-r kwd-c false)))))
+
 (deftest find-definition-from-cursor
   (let [code (str "(ns a.b.c (:require [d.e.f :as |f-alias]))\n"
                   "(defn |x [|filename] |filename |f-alias/foo)\n"
@@ -520,6 +552,36 @@
       {:name 'd.e.f :bucket :namespace-definitions}
       (q/find-definition-from-cursor db (h/file-uri "file:///a.clj") alias-r alias-c))))
 
+(deftest find-definition-from-cursor-with-quoted-symbol
+  (h/load-code-and-locs "(ns foo) (defn foo [])" (h/file-uri "file:///foo.clj"))
+  (h/load-code-and-locs "(ns bar) (defn bar [])" (h/file-uri "file:///bar.clj"))
+  (let [code (h/code "(ns a (:require [foo :as f]))"
+                     "'foo/foo|"
+                     "'f/foo|"
+                     "'bar/bar|")
+        [[foo-r foo-c] [foo-alias-r foo-alias-c] [bar-r bar-c]]
+        (h/load-code-and-locs code (h/file-uri "file:///a.clj"))
+        db (h/db)]
+    (h/assert-submap
+      {:name 'foo :ns 'foo :col 10}
+      (q/find-definition-from-cursor db (h/file-uri "file:///a.clj") foo-r foo-c))
+    (h/assert-submap
+      {:name 'foo :ns 'foo :col 10}
+      (q/find-definition-from-cursor db (h/file-uri "file:///a.clj") foo-alias-r foo-alias-c))
+    (h/assert-submap
+      {:name 'bar :ns 'bar :col 10}
+      (q/find-definition-from-cursor db (h/file-uri "file:///a.clj") bar-r bar-c))))
+
+(deftest find-definition-from-cursor-with-symbol-in-edn-file
+  (h/load-code-and-locs "(ns exec-ns) (defn foo [])" (h/file-uri "file:///exec_ns.clj"))
+  (let [code (h/code "{:aliases {:foo {:exec-fn |exec-ns/foo}}}")
+        [[exec-fn-r exec-fn-c]]
+        (h/load-code-and-locs code (h/file-uri "file:///deps.edn"))
+        db (h/db)]
+    (h/assert-submap
+      {:name 'foo :ns 'exec-ns :row 1 :col 14}
+      (q/find-definition-from-cursor db (h/file-uri "file:///deps.edn") exec-fn-r exec-fn-c))))
+
 (deftest find-definition-from-cursor-when-duplicate-from-external-analysis
   (let [_ (h/load-code-and-locs (h/code "(ns foo) (def bar)") "zipfile:///some.jar::some-jar.clj")
         _ (h/load-code-and-locs (h/code "(ns foo) (def bar)") (h/file-uri "file:///a.clj"))
